# ospyata

![Python](https://ForTheBadge.com/images/badges/made-with-python.svg)
![Built with :heart:](https://ForTheBadge.com/images/badges/built-with-love.svg)

![Maintained](https://img.shields.io/badge/Maintained%3F-yes-green.svg)
![Issues Open](https://img.shields.io/github/issues/aerocyber/ospyata.svg)
![Issues Closed](https://img.shields.io/github/issues-closed/aerocyber/ospyata.svg)
![Pull Requests Open](https://img.shields.io/github/issues-pr/aerocyber/ospyata.svg)
![Pull Requests Closed](https://img.shields.io/github/issues-pr-closed/aerocyber/ospyata)
![Maintainer](https://img.shields.io/badge/maintainer-aerocyber-blue)
[![PyPi version](https://badgen.net/pypi/v/ospyata/)](https://pypi.com/project/ospyata)
[![GitHub license](https://badgen.net/github/license/aerocyber/ospyata)](https://github.com/aerocyber/ospyata/blob/master/LICENSE)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/ospyata.svg)](https://pypi.python.org/pypi/ospyata/)

Python bindings for osmata

## Docs

Visit [Docs](https://aerocyber.github.io/ospyata/docs/) page!

### LICENSE

> MIT License

See [LICENSE file](https://github.com/aerocyber/ospyata/blob/main/LICENSE)

### Support

Financially: [Buy me a coffee](https://www.buymeacoffee.com/aerocyber)
Code/Documentation: [Open a PR](https://github.com/aerocyber/ospyata/pulls)
Error reporting: [Open an issue](https://github.com/aerocyber/ospyata/issues)
